@@ -278,9 +278,7 @@ class Swift_PPST(
 
         # We need at least one key to be set
         if total_keys == 0:
-            self.status.error(
-                "Please supply search parameters to narrow search."
-            )
+            self.status.error("Please supply search parameters to narrow search.")
             return False
 
         # Check if ra or dec are in keys, we have both.
